@@ -1,6 +1,11 @@
+from unittest.case import skipIf
+
 from integration.helpers.base_test import BaseTest
+from integration.helpers.resource import current_region_does_not_support
+from integration.config.service_names import LAYERS
 
 
+@skipIf(current_region_does_not_support([LAYERS]), "Layers is not supported in this testing region")
 class TestFunctionWithLayers(BaseTest):
     def test_function_with_layer(self):
         self.create_and_verify_stack("combination/function_with_layer")
