@@ -1,6 +1,11 @@
+from unittest.case import skipIf
+
 from integration.helpers.base_test import BaseTest
+from integration.helpers.resource import current_region_does_not_support
+from integration.config.service_names import S3_EVENTS
 
 
+@skipIf(current_region_does_not_support([S3_EVENTS]), "S3 Events feature is not supported in this testing region")
 class TestFunctionWithS3Bucket(BaseTest):
     def test_function_with_s3_bucket_trigger(self):
         self.create_and_verify_stack("combination/function_with_s3")
