@@ -1,4 +1,5 @@
 from parameterized import parameterized, param
+from datetime import datetime
 from unittest import TestCase
 from unittest.mock import MagicMock, call, ANY
 from samtranslator.metrics.metrics import (
@@ -30,25 +31,43 @@ class TestMetrics(TestCase):
                 "CountMetric",
                 12,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                None,
             ),
             param(
                 "DummyNamespace",
                 "IAMError",
                 59,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                None,
+            ),
+            param(
+                "DummyNamespace",
+                "MyCount",
+                77,
+                [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                datetime(2022, 8, 11, 0, 0, 0),
             ),
         ]
     )
-    def test_publishing_count_metric(self, namespace, name, value, dimensions):
+    def test_publishing_count_metric(self, namespace, name, value, dimensions, timestamp):
         mock_metrics_publisher = MetricPublisherTestHelper()
         metrics = Metrics(namespace, mock_metrics_publisher)
-        metrics.record_count(name, value, dimensions)
+        kwargs = {
+            "name": name,
+            "value": value,
+            "dimensions": dimensions,
+        }
+        if timestamp is not None:
+            kwargs["timestamp"] = timestamp
+        metrics.record_count(**kwargs)
         metrics.publish()
         self.assertEqual(len(mock_metrics_publisher.metrics_cache), 1)
         published_metric = mock_metrics_publisher.metrics_cache[0].get_metric_data()
         self.assertEqual(published_metric["MetricName"], name)
         self.assertEqual(published_metric["Dimensions"], dimensions)
         self.assertEqual(published_metric["Value"], value)
+        if timestamp is not None:
+            self.assertEqual(published_metric["Timestamp"], timestamp)
 
     @parameterized.expand(
         [
@@ -57,25 +76,43 @@ class TestMetrics(TestCase):
                 "SARLatency",
                 1200,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                None,
             ),
             param(
                 "DummyNamespace",
                 "IAMLatency",
                 400,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                None,
+            ),
+            param(
+                "DummyNamespace",
+                "OtherLatency",
+                400000,
+                [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                datetime(2021, 9, 20, 12, 0, 0),
             ),
         ]
     )
-    def test_publishing_latency_metric(self, namespace, name, value, dimensions):
+    def test_publishing_latency_metric(self, namespace, name, value, dimensions, timestamp):
         mock_metrics_publisher = MetricPublisherTestHelper()
         metrics = Metrics(namespace, mock_metrics_publisher)
-        metrics.record_latency(name, value, dimensions)
+        kwargs = {
+            "name": name,
+            "value": value,
+            "dimensions": dimensions,
+        }
+        if timestamp is not None:
+            kwargs["timestamp"] = timestamp
+        metrics.record_latency(**kwargs)
         metrics.publish()
         self.assertEqual(len(mock_metrics_publisher.metrics_cache), 1)
         published_metric = mock_metrics_publisher.metrics_cache[0].get_metric_data()
         self.assertEqual(published_metric["MetricName"], name)
         self.assertEqual(published_metric["Dimensions"], dimensions)
         self.assertEqual(published_metric["Value"], value)
+        if timestamp is not None:
+            self.assertEqual(published_metric["Timestamp"], timestamp)
 
     @parameterized.expand(
         [
@@ -153,6 +190,7 @@ class TestCWMetricPublisher(TestCase):
                 12,
                 Unit.Count,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                None,
             ),
             param(
                 "DummyNamespace",
@@ -160,6 +198,7 @@ class TestCWMetricPublisher(TestCase):
                 59,
                 Unit.Count,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                datetime(2022, 8, 8, 8, 8, 8),
             ),
             param(
                 "DummyNamespace",
@@ -167,6 +206,7 @@ class TestCWMetricPublisher(TestCase):
                 1200,
                 Unit.Milliseconds,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                None,
             ),
             param(
                 "DummyNamespace",
@@ -174,20 +214,28 @@ class TestCWMetricPublisher(TestCase):
                 400,
                 Unit.Milliseconds,
                 [{"Name": "SAM", "Value": "Dim1"}, {"Name": "SAM", "Value": "Dim2"}],
+                datetime(2021, 9, 10, 10, 10, 10),
             ),
         ]
     )
-    def test_publish_metric(self, namespace, name, value, unit, dimensions):
+    def test_publish_metric(self, namespace, name, value, unit, dimensions, timestamp):
         mock_cw_client = MagicMock()
         metric_publisher = CWMetricsPublisher(mock_cw_client)
-        metric_datum = MetricDatum(name, value, unit, dimensions)
+        metric_datum = MetricDatum(name, value, unit, dimensions, timestamp)
         metrics = [metric_datum]
         metric_publisher.publish(namespace, metrics)
+        expected_timestamp = timestamp if timestamp is not None else ANY
         mock_cw_client.put_metric_data.assert_has_calls(
             [
                 call(
                     MetricData=[
-                        {"Dimensions": dimensions, "Unit": unit, "Value": value, "MetricName": name, "Timestamp": ANY}
+                        {
+                            "Dimensions": dimensions,
+                            "Unit": unit,
+                            "Value": value,
+                            "MetricName": name,
+                            "Timestamp": expected_timestamp,
+                        }
                     ],
                     Namespace=namespace,
                 )
