@@ -1,5 +1,6 @@
 from unittest.mock import Mock, patch
 from unittest import TestCase
+from parameterized import parameterized
 
 from samtranslator.model.eventsources.push import EventBridgeRule
 from samtranslator.model.lambda_ import LambdaFunction
@@ -82,3 +83,33 @@ class EventBridgeRuleSourceTests(TestCase):
         self.eb_event_source.DeadLetterConfig = dead_letter_config
         with self.assertRaises(InvalidEventException):
             self.eb_event_source.to_cloudformation(function=self.func)
+
+    def test_to_cloudformation_transforms_enabled_boolean_to_state(self):
+        self.eb_event_source.Enabled = True
+        resources = self.eb_event_source.to_cloudformation(function=self.func)
+        self.assertEqual(len(resources), 2)
+        event_rule = resources[0]
+        self.assertEqual(event_rule.State, "ENABLED")
+
+        self.eb_event_source.Enabled = False
+        resources = self.eb_event_source.to_cloudformation(function=self.func)
+        self.assertEqual(len(resources), 2)
+        event_rule = resources[0]
+        self.assertEqual(event_rule.State, "DISABLED")
+
+    @parameterized.expand(
+        [
+            (True, "ENABLED"),
+            (True, "DISABLED"),
+            (True, {"FN:FakeIntrinsic": "something"}),
+            (False, "ENABLED"),
+            (False, "DISABLED"),
+            (False, {"FN:FakeIntrinsic": "something"}),
+        ]
+    )
+    def test_to_cloudformation_invalid_defined_both_enabled_and_state_provided(self, enabled_value, state_value):
+        self.maxDiff = None
+        self.eb_event_source.Enabled = enabled_value
+        self.eb_event_source.State = state_value
+        with self.assertRaises(InvalidEventException):
+            self.eb_event_source.to_cloudformation(function=self.func)
